==> haskell-filestore-0.6.5.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filestore
version:              0.6.5.1
visibility:           public
id:                   filestore-0.6.5.1-Bt6h51mNWzd4Kz9fP5uDAT
key:                  filestore-0.6.5.1-Bt6h51mNWzd4Kz9fP5uDAT
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  bfb3563c7c83fa689d175760eb23af5c
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5.1-Bt6h51mNWzd4Kz9fP5uDAT
depends:
    Diff-0.4.1-54jN24YTNqv3C30Bh41O9s base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    process-1.6.18.0 split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV time-1.12.2
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filestore-0.6.5.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filestore
version:              0.6.5.1
visibility:           public
id:                   filestore-0.6.5.1-AyNCILZFYWe6cI6234WPTk
key:                  filestore-0.6.5.1-AyNCILZFYWe6cI6234WPTk
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  e9b3fcaf4de88b684f093c1f9ab6bb20
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filestore-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5.1-AyNCILZFYWe6cI6234WPTk
depends:
    Diff-0.4.1-ET3XsIdmMuHEEbo255V0kN base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    process-1.6.18.0 split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV time-1.12.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
